@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: awgn.c,v 1.10 2006/10/24 13:45:25 steveu Exp $
+ * $Id: awgn.c,v 1.12 2007/11/26 13:28:58 steveu Exp $
  */
 
 /*! \file */
@@ -47,9 +47,13 @@
 #endif
 
 #include <stdlib.h>
-#include <stdio.h>
 #include <inttypes.h>
+#if defined(HAVE_TGMATH_H)
 #include <tgmath.h>
+#endif
+#if defined(HAVE_MATH_H)
+#include <math.h>
+#endif
 
 #include "spandsp/telephony.h"
 #include "spandsp/dc_restore.h"
@@ -79,8 +83,8 @@ static double ran1(awgn_state_t *s)
     j = 1 + ((97*s->ix3)/M3);
     if (j > 97  ||  j < 1)
     {
-        fprintf(stderr, "Random number generator error - %d\n", j);
-        exit(-1);
+        /* Error */
+        return -1;
     }
     temp = s->r[j];
     s->r[j] = (s->ix1 + s->ix2*RM2)*RM1;
@@ -88,16 +92,21 @@ static double ran1(awgn_state_t *s)
 }
 /*- End of function --------------------------------------------------------*/
 
-void awgn_init_dbm0(awgn_state_t *s, int idum, float level)
+awgn_state_t *awgn_init_dbm0(awgn_state_t *s, int idum, float level)
 {
-    awgn_init_dbov(s, idum, level - DBM0_MAX_POWER);
+    return awgn_init_dbov(s, idum, level - DBM0_MAX_POWER);
 }
 /*- End of function --------------------------------------------------------*/
 
-void awgn_init_dbov(awgn_state_t *s, int idum, float level)
+awgn_state_t *awgn_init_dbov(awgn_state_t *s, int idum, float level)
 {
     int j;
 
+    if (s == NULL)
+    {
+        if ((s = (awgn_state_t *) malloc(sizeof(*s))) == NULL)
+            return  NULL;
+    }
     if (idum < 0)
         idum = -idum;
 
@@ -117,6 +126,7 @@ void awgn_init_dbov(awgn_state_t *s, int idum, float level)
     }
     s->gset = 0.0;
     s->iset = 0;
+    return s;
 }
 /*- End of function --------------------------------------------------------*/
 
