@@ -26,7 +26,7 @@
  * implementation of the LPC-10 2400 bps Voice Coder. They do not
  * exert copyright claims on their code, and it may be freely used.
  *
- * $Id: lpc10_analyse.c,v 1.5 2006/10/24 13:45:25 steveu Exp $
+ * $Id: lpc10_analyse.c,v 1.13 2007/01/03 14:15:35 steveu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,7 +37,12 @@
 #include <stdio.h>
 #include <inttypes.h>
 #include <memory.h>
+#if defined(HAVE_TGMATH_H)
 #include <tgmath.h>
+#endif
+#if defined(HAVE_MATH_H)
+#include <math.h>
+#endif
 
 #include "spandsp/telephony.h"
 #include "spandsp/dc_restore.h"
@@ -52,8 +57,8 @@ static __inline__ float energyf(float amp[], int len)
 
     rms = 0.0f;
     for (i = 0;  i < len;  i++)
-	    rms += amp[i]*amp[i];
-    rms = sqrt(rms/len);
+        rms += amp[i]*amp[i];
+    rms = sqrtf(rms/len);
     return rms;
 }
 /*- End of function --------------------------------------------------------*/
@@ -127,7 +132,7 @@ static void eval_highres_amdf(float speech[],
     /* Compute full AMDF using log spaced lags, find coarse minimum */
     eval_amdf(speech, lpita, tau, ltau, tau[ltau - 1], amdf, minptr, maxptr);
     *mintau = tau[*minptr];
-    minamd = amdf[*minptr];
+    minamd = (int32_t) amdf[*minptr];
 
     /* Build table containing all lags within +/- 3 of the AMDF minimum,
        excluding all that have already been computed */
@@ -149,7 +154,7 @@ static void eval_highres_amdf(float speech[],
         if (amdf2[minp2] < (float) minamd)
         {
             *mintau = tau2[minp2];
-            minamd = amdf2[minp2];
+            minamd = (int32_t) amdf2[minp2];
         }
     }
     /* Check one octave up, if there are any lags not yet computed */
@@ -171,7 +176,7 @@ static void eval_highres_amdf(float speech[],
         if (amdf2[minp2] < (float) minamd)
         {
             *mintau = tau2[minp2];
-            minamd = amdf2[minp2];
+            minamd = (int32_t) amdf2[minp2];
             *minptr -= 20;
         }
     }
@@ -192,7 +197,7 @@ static void dynamic_pitch_tracking(lpc10_encode_state_t *s,
                                    float amdf[],
                                    int32_t ltau,
                                    int32_t *minptr,
-                                   int32_t *voice,
+                                   int32_t voice,
                                    int32_t *pitch,
                                    int32_t *midx)
 {
@@ -209,16 +214,16 @@ static void dynamic_pitch_tracking(lpc10_encode_state_t *s,
     /* SEESAW.  If unvoiced, set high slope so that every point in P array */
     /*is marked as a potential pitch frequency.  A scaled up version (ALPHAX )*/
     /* is used to maintain arithmetic precision. */
-    if (*voice == 1)
+    if (voice == 1)
         s->alphax = s->alphax*0.75f + amdf[*minptr - 1]*0.5f;
     else
         s->alphax *= 0.984375f;
     alpha = s->alphax/16;
-    if (*voice == 0  &&  s->alphax < 128.0f)
+    if (voice == 0  &&  s->alphax < 128.0f)
         alpha = 8.0f;
     /* SEESAW: Construct a pitch pointer array and intermediate winner function */
     /* Left to right pass: */
-    s->p[s->ipoint*60] = 1;
+    s->p[s->ipoint][0] = 1;
     pbar = 1;
     sbar = s->s[0];
     for (i = 0;  i < ltau;  i++)
@@ -233,7 +238,7 @@ static void dynamic_pitch_tracking(lpc10_encode_state_t *s,
             pbar = i + 1;
             sbar = s->s[i];
         }
-        s->p[i + s->ipoint*60] = pbar;
+        s->p[s->ipoint][i] = pbar;
     }
     /* Right to left pass: */
     sbar = s->s[pbar - 1];
@@ -243,11 +248,11 @@ static void dynamic_pitch_tracking(lpc10_encode_state_t *s,
         if (sbar < s->s[i])
         {
             s->s[i] = sbar;
-            s->p[i + s->ipoint*60] = pbar;
+            s->p[s->ipoint][i] = pbar;
         }
         else
         {
-            pbar = s->p[i + s->ipoint*60];
+            pbar = s->p[s->ipoint][i];
             i = pbar - 1;
             sbar = s->s[i];
         }
@@ -288,7 +293,7 @@ static void dynamic_pitch_tracking(lpc10_encode_state_t *s,
     *pitch = *midx;
     for (i = 0, j = s->ipoint;  i < 2;  i++, j++)
     {
-        *pitch = s->p[*pitch - 1 + (j & 1)*60];
+        *pitch = s->p[j & 1][*pitch - 1];
         path[i] = *pitch;
     }
 
@@ -317,7 +322,7 @@ static void onset(lpc10_encode_state_t *s,
     pebuf -= sbufl;
 
     if (s->hyst)
-    	s->lasti -= lframe;
+        s->lasti -= lframe;
     for (i = sbufh - lframe + 1;  i <= sbufh;  i++)
     {
         /* Compute FPC; Use old FPC on divide by zero; Clamp FPC to +/- 1. */
@@ -364,43 +369,38 @@ static void onset(lpc10_encode_state_t *s,
 /*- End of function --------------------------------------------------------*/
 
 /* Load a covariance matrix. */
-static void mload(int32_t order, int32_t awins, int32_t awinf, float *speech, float *phi, float psi[])
+static void mload(int32_t order, int32_t awins, int32_t awinf, float speech[], float phi[], float psi[])
 {
-    int32_t phi_dim1;
-    int32_t phi_offset;
     int32_t start;
     int i;
     int r;
 
-    phi_dim1 = order;
-    phi_offset = phi_dim1 + 1;
-    phi -= phi_offset;
-
     start = awins + order;
     for (r = 1;  r <= order;  r++)
     {
-        phi[r + phi_dim1] = 0.0f;
+        phi[r - 1] = 0.0f;
         for (i = start;  i <= awinf;  i++)
-            phi[r + phi_dim1] += speech[i - 2]*speech[i - r - 1];
+            phi[r - 1] += speech[i - 2]*speech[i - r - 1];
     }
+
     /* Load last element of vector PSI */
     psi[order - 1] = 0.0f;
     for (i = start - 1;  i < awinf;  i++)
         psi[order - 1] += speech[i]*speech[i - order];
-    /* End correct to get additional columns of PHI */
-    for (r = 2;  r <= order;  r++)
+    /* End correct to get additional columns of phi */
+    for (r = 1;  r < order;  r++)
     {
-        for (i = 2;  i <= r;  i++)
+        for (i = 1;  i <= r;  i++)
         {
-            phi[r + i*phi_dim1] = phi[r - 1 + (i - 1)*phi_dim1]
-                                 - speech[awinf - r]*speech[awinf - i]
-                                 + speech[start - r - 1]*speech[start - i - 1];
+            phi[i*order + r] = phi[(i - 1)*order + r - 1]
+                             - speech[awinf - (r + 1)]*speech[awinf - (i + 1)]
+                             + speech[start - (r + 2)]*speech[start - (i + 2)];
         }
     }
     /* End correct to get additional elements of PSI */
     for (i = 0;  i < order - 1;  i++)
     {
-        psi[i] = phi[phi_dim1 + i + 2]
+        psi[i] = phi[i + 1]
                - speech[start - 2]*speech[start - i - 3]
                + speech[awinf - 1]*speech[awinf - i - 2];
     }
@@ -409,7 +409,6 @@ static void mload(int32_t order, int32_t awins, int32_t awinf, float *speech, fl
 
 /* Preemphasize speech with a single-zero filter. */
 /* (When coef = .9375, preemphasis is as in LPC43.) */
-
 static float preemp(float inbuf[], float pebuf[], int nsamp, float coeff, float z)
 {
     float temp;
@@ -426,7 +425,6 @@ static float preemp(float inbuf[], float pebuf[], int nsamp, float coeff, float
 /*- End of function --------------------------------------------------------*/
 
 /* Invert a covariance matrix using Choleski decomposition method. */
-
 static void invert(int32_t order, float phi[], float psi[], float rc[])
 {
     float r1;
@@ -550,7 +548,7 @@ static void ivfilt(float lpbuf[], float ivbuf[], int32_t len, int32_t nsamp, flo
 }
 /*- End of function --------------------------------------------------------*/
 
-void lpc10_analyse(lpc10_encode_state_t *s, float speech[], int32_t voice[], int32_t *pitch, float *rms, float *rc)
+void lpc10_analyse(lpc10_encode_state_t *s, float speech[], int32_t voice[], int32_t *pitch, float *rms, float rc[])
 {
     static const int32_t tau[60] =
     {
@@ -574,7 +572,7 @@ void lpc10_analyse(lpc10_encode_state_t *s, float speech[], int32_t voice[], int
     float psi[10];
     int32_t half;
     int32_t midx;
-    int32_t ewin[6];
+    int32_t ewin[3][2];
     int32_t i;
     int32_t j;
     int32_t lanal;
@@ -602,20 +600,20 @@ void lpc10_analyse(lpc10_encode_state_t *s, float speech[], int32_t voice[], int
             s->osbuf[j++] = s->osbuf[i] - LPC10_SAMPLES_PER_FRAME;
     }
     s->osptr = j + 1;
-    s->voibuf[0] = s->voibuf[2];
-    s->voibuf[1] = s->voibuf[3];
-    for (i = 1;  i <= 2;  i++)
+    s->voibuf[0][0] = s->voibuf[1][0];
+    s->voibuf[0][1] = s->voibuf[1][1];
+    for (i = 0;  i < 2;  i++)
     {
-        s->vwin[(i << 1) - 2] = s->vwin[((i + 1) << 1) - 2] - LPC10_SAMPLES_PER_FRAME;
-        s->vwin[(i << 1) - 1] = s->vwin[((i + 1) << 1) - 1] - LPC10_SAMPLES_PER_FRAME;
-        s->awin[(i << 1) - 2] = s->awin[((i + 1) << 1) - 2] - LPC10_SAMPLES_PER_FRAME;
-        s->awin[(i << 1) - 1] = s->awin[((i + 1) << 1) - 1] - LPC10_SAMPLES_PER_FRAME;
-        s->obound[i - 1] = s->obound[i];
-        s->voibuf[i << 1] = s->voibuf[(i + 1) << 1];
-        s->voibuf[(i << 1) + 1] = s->voibuf[((i + 1) << 1) + 1];
-        s->rmsbuf[i - 1] = s->rmsbuf[i];
+        s->vwin[i][0] = s->vwin[i + 1][0] - LPC10_SAMPLES_PER_FRAME;
+        s->vwin[i][1] = s->vwin[i + 1][1] - LPC10_SAMPLES_PER_FRAME;
+        s->awin[i][0] = s->awin[i + 1][0] - LPC10_SAMPLES_PER_FRAME;
+        s->awin[i][1] = s->awin[i + 1][1] - LPC10_SAMPLES_PER_FRAME;
+        s->obound[i] = s->obound[i + 1];
+        s->voibuf[i + 1][0] = s->voibuf[i + 2][0];
+        s->voibuf[i + 1][1] = s->voibuf[i + 2][1];
+        s->rmsbuf[i] = s->rmsbuf[i + 1];
         for (j = 0;  j < LPC10_ORDER;  j++)
-            s->rcbuf[j + (i - 1)*10] = s->rcbuf[j + i*10];
+            s->rcbuf[i][j] = s->rcbuf[i + 1][j];
     }
     /* If the average value in the frame was over 1/4096 (after current
        BIAS correction), then subtract that much more from samples in the
@@ -629,10 +627,10 @@ void lpc10_analyse(lpc10_encode_state_t *s, float speech[], int32_t voice[], int
         temp += s->inbuf[720 - 2*LPC10_SAMPLES_PER_FRAME + i];
     }
     if (temp > (float) LPC10_SAMPLES_PER_FRAME)
-        s->bias += 1;
-    if (temp < (float) (-LPC10_SAMPLES_PER_FRAME))
-        s->bias += -1;
-    /* Place Voicing Window */
+        s->bias++;
+    else if (temp < (float) (-LPC10_SAMPLES_PER_FRAME))
+        s->bias--;
+    /* Place voicing window */
     i = 721 - LPC10_SAMPLES_PER_FRAME;
     s->zpre = preemp(&s->inbuf[i - 181], &s->pebuf[i - 181], LPC10_SAMPLES_PER_FRAME, precoef, s->zpre);
     onset(s, s->pebuf, s->osbuf, &s->osptr, 10, 181, 720, LPC10_SAMPLES_PER_FRAME);
@@ -673,33 +671,42 @@ void lpc10_analyse(lpc10_encode_state_t *s, float speech[], int32_t voice[], int
        voicing decisions. */
     for (half = 0;  half < 2;  half++)
     {
-        lpc10_voicing(s, &s->vwin[4], s->inbuf, s->lpbuf, buflim, half, &amdf[minptr],
-                     &amdf[maxptr], &mintau, ivrc, s->obound);
+        lpc10_voicing(s,
+                      &s->vwin[2][0],
+                      s->inbuf,
+                      s->lpbuf,
+                      buflim,
+                      half,
+                      &amdf[minptr],
+                      &amdf[maxptr],
+                      &mintau,
+                      ivrc,
+                      s->obound);
     }
-    /* Find the minimum cost pitch decision over several frames */
-    /* given the current voicing decision and the AMDF array */
+    /* Find the minimum cost pitch decision over several frames,
+       given the current voicing decision and the AMDF array */
     minptr++;
-    dynamic_pitch_tracking(s, amdf, 60, &minptr, &s->voibuf[7], pitch, &midx);
+    dynamic_pitch_tracking(s, amdf, 60, &minptr, s->voibuf[3][1], pitch, &midx);
     ipitch = tau[midx - 1];
     /* Place spectrum analysis and energy windows */
     lpc10_placea(&ipitch, s->voibuf, &s->obound[2], 3, s->vwin, s->awin, ewin, LPC10_SAMPLES_PER_FRAME, 156);
-    /* Remove short term DC bias over the analysis window, Put result in ABUF */
-    lanal = s->awin[5] + 1 - s->awin[4];
-    remove_dc_bias(&s->pebuf[s->awin[4] - 181], lanal, abuf);
-    /* Compute RMS over int32_t number of pitch periods within the analysis window. */
-    /* Note that in a hardware implementation this computation may be */
-    /* simplified by using diagonal elements of PHI computed by MLOAD. */
-    s->rmsbuf[2] = energyf(&abuf[ewin[4] - s->awin[4]], ewin[5] - ewin[4] + 1);
+    /* Remove short term DC bias over the analysis window. */
+    lanal = s->awin[2][1] + 1 - s->awin[2][0];
+    remove_dc_bias(&s->pebuf[s->awin[2][0] - 181], lanal, abuf);
+    /* Compute RMS over integer number of pitch periods within the analysis window. */
+    /* Note that in a hardware implementation this computation may be
+       simplified by using diagonal elements of phi computed by mload(). */
+    s->rmsbuf[2] = energyf(&abuf[ewin[2][0] - s->awin[2][0]], ewin[2][1] - ewin[2][0] + 1);
     /* Matrix load and invert, check RC's for stability */
     mload(LPC10_ORDER, 1, lanal, abuf, phi, psi);
-    invert(LPC10_ORDER, phi, psi, &s->rcbuf[20]);
-    rcchk(LPC10_ORDER, &s->rcbuf[10], &s->rcbuf[20]);
+    invert(LPC10_ORDER, phi, psi, &s->rcbuf[2][0]);
+    rcchk(LPC10_ORDER, &s->rcbuf[1][0], &s->rcbuf[2][0]);
     /* Set return parameters */
-    voice[0] = s->voibuf[2];
-    voice[1] = s->voibuf[3];
+    voice[0] = s->voibuf[1][0];
+    voice[1] = s->voibuf[1][1];
     *rms = s->rmsbuf[0];
     for (i = 0;  i < LPC10_ORDER;  i++)
-        rc[i] = s->rcbuf[i];
+        rc[i] = s->rcbuf[0][i];
 }
 /*- End of function --------------------------------------------------------*/
 /*- End of file ------------------------------------------------------------*/
