@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: power_meter.c,v 1.19 2007/04/10 16:12:19 steveu Exp $
+ * $Id: power_meter.c,v 1.20 2007/11/26 13:28:59 steveu Exp $
  */
 
 /*! \file */
@@ -51,11 +51,12 @@
 power_meter_t *power_meter_init(power_meter_t *s, int shift)
 {
     if (s == NULL)
-        return NULL;
+    {
+        if ((s = (power_meter_t *) malloc(sizeof(*s))) == NULL)
+            return NULL;
+    }
     s->shift = shift;
     s->reading = 0;
-    s->high_sample = 0;
-    s->low_samples = 0;
     return s;
 }
 /*- End of function --------------------------------------------------------*/
@@ -70,20 +71,6 @@ power_meter_t *power_meter_damping(power_meter_t *s, int shift)
 int32_t power_meter_update(power_meter_t *s, int16_t amp)
 {
     s->reading += ((amp*amp - s->reading) >> s->shift);
-    if (abs(amp) < abs(s->high_sample / 10))
-    {
-        if (++s->low_samples > 120)
-        {
-            s->reading = 0;
-            s->high_sample = 0;
-            s->low_samples = 0;
-        }
-    }
-    else
-    {
-	s->low_samples = 0;
-	if (abs(s->high_sample) < abs(amp)) s->high_sample = amp;
-    }
     return s->reading;
 }
 /*- End of function --------------------------------------------------------*/
