@@ -23,13 +23,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: dc_restore.h,v 1.14 2006/10/24 13:45:28 steveu Exp $
+ * $Id: dc_restore.h,v 1.18 2007/04/08 08:16:17 steveu Exp $
  */
 
 /*! \file */
 
-#if !defined(_DC_RESTORE_H_)
-#define _DC_RESTORE_H_
+#if !defined(_SPANDSP_DC_RESTORE_H_)
+#define _SPANDSP_DC_RESTORE_H_
 
 /*! \page dc_restore_page Removing DC bias from a signal
 
@@ -61,8 +61,9 @@ typedef struct
     int32_t state;
 } dc_restore_state_t;
 
-#ifdef __cplusplus
-extern "C" {
+#if defined(__cplusplus)
+extern "C"
+{
 #endif
 
 static __inline__ void dc_restore_init(dc_restore_state_t *dc)
@@ -104,7 +105,7 @@ static __inline__ int16_t fsaturatef(float famp)
         return  INT16_MAX;
     if (famp < -32768.0)
         return  INT16_MIN;
-    return (int16_t) lrintf(famp);
+    return (int16_t) rintf(famp);
 }
 /*- End of function --------------------------------------------------------*/
 
@@ -114,11 +115,11 @@ static __inline__ int16_t fsaturate(double damp)
         return  INT16_MAX;
     if (damp < -32768.0)
         return  INT16_MIN;
-    return (int16_t) lrint(damp);
+    return (int16_t) rint(damp);
 }
 /*- End of function --------------------------------------------------------*/
 
-#ifdef __cplusplus
+#if defined(__cplusplus)
 }
 #endif
 
