@@ -23,13 +23,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: noise.h,v 1.8 2006/10/24 13:45:28 steveu Exp $
+ * $Id: noise.h,v 1.11 2007/04/08 08:16:18 steveu Exp $
  */
 
 /*! \file */
 
-#if !defined(_NOISE_H_)
-#define _NOISE_H_
+#if !defined(_SPANDSP_NOISE_H_)
+#define _SPANDSP_NOISE_H_
 
 /*! \page noise_page Noise generation
 
@@ -100,8 +100,9 @@ typedef struct
     int32_t state;
 } noise_state_t;
 
-#ifdef __cplusplus
-extern "C" {
+#if defined(__cplusplus)
+extern "C"
+{
 #endif
 
 /*! Initialise an audio noise generator.
@@ -125,7 +126,7 @@ noise_state_t *noise_init_dbov(noise_state_t *s, int seed, float level, int clas
 */
 int16_t noise(noise_state_t *s);
 
-#ifdef __cplusplus
+#if defined(__cplusplus)
 }
 #endif
 
