@@ -22,11 +22,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: super_tone_rx.h,v 1.9 2006/10/24 13:22:02 steveu Exp $
+ * $Id: super_tone_rx.h,v 1.14 2007/12/13 11:31:33 steveu Exp $
  */
 
-#if !defined(_SUPER_TONE_RX_H_)
-#define _SUPER_TONE_RX_H_
+#if !defined(_SPANDSP_SUPER_TONE_RX_H_)
+#define _SPANDSP_SUPER_TONE_RX_H_
 
 /*! \page super_tone_rx_page Supervisory tone detection
 
@@ -55,7 +55,7 @@ executive override tone, confirmation tone).
 */
 
 /*! Tone detection indication callback routine */
-typedef void (*tone_report_func_t)(void *user_data, int code);
+typedef void (*tone_report_func_t)(void *user_data, int code, int level, int delay);
 
 #define BINS            128
 
@@ -93,6 +93,11 @@ typedef struct
     goertzel_state_t state[];
 } super_tone_rx_state_t;
 
+#if defined(__cplusplus)
+extern "C"
+{
+#endif
+
 /*! Create a new supervisory tone detector descriptor.
     \param desc The supervisory tone set desciptor. If NULL, the routine will allocate space for a
                 descriptor.
@@ -161,7 +166,11 @@ void super_tone_rx_segment_callback(super_tone_rx_state_t *s,
     \param samples The number of samples in the buffer.
     \return The number of samples processed.
 */
-int super_tone_rx(super_tone_rx_state_t *super, const int16_t *amp, int samples);
+int super_tone_rx(super_tone_rx_state_t *super, const int16_t amp[], int samples);
+
+#if defined(__cplusplus)
+}
+#endif
 
 #endif
 /*- End of file ------------------------------------------------------------*/
