@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: t31.h,v 1.43 2007/05/15 13:22:43 steveu Exp $
+ * $Id: t31.h,v 1.45 2007/12/29 05:35:32 steveu Exp $
  */
 
 /*! \file */
@@ -73,6 +73,9 @@ struct t31_state_s
         silent audio. */
     int transmit_on_idle;
 
+    /*! \brief Use talker echo protection when transmitting. */
+    int use_tep;    
+
     uint8_t hdlc_tx_buf[256];
     int hdlc_tx_len;
     int hdlc_tx_ptr;
@@ -101,24 +104,17 @@ struct t31_state_s
     hdlc_tx_state_t hdlctx;
     /*! \brief A V.21 FSK modem context used when transmitting HDLC over V.21
                messages. */
-    fsk_tx_state_t v21tx;
+    fsk_tx_state_t v21_tx;
     /*! \brief A V.21 FSK modem context used when receiving HDLC over V.21
                messages. */
-    fsk_rx_state_t v21rx;
+    fsk_rx_state_t v21_rx;
 
     /*! \brief A V.17 modem context used when sending FAXes at 7200bps, 9600bps
                12000bps or 14400bps*/
-    v17_tx_state_t v17tx;
+    v17_tx_state_t v17_tx;
     /*! \brief A V.29 modem context used when receiving FAXes at 7200bps, 9600bps
                12000bps or 14400bps*/
-    v17_rx_state_t v17rx;
-
-    /*! \brief A V.29 modem context used when sending FAXes at 7200bps or
-               9600bps */
-    v29_tx_state_t v29tx;
-    /*! \brief A V.29 modem context used when receiving FAXes at 7200bps or
-               9600bps */
-    v29_rx_state_t v29rx;
+    v17_rx_state_t v17_rx;
 
     /*! \brief A V.27ter modem context used when sending FAXes at 2400bps or
                4800bps */
@@ -127,6 +123,13 @@ struct t31_state_s
                4800bps */
     v27ter_rx_state_t v27ter_rx;
 
+    /*! \brief A V.29 modem context used when sending FAXes at 7200bps or
+               9600bps */
+    v29_tx_state_t v29_tx;
+    /*! \brief A V.29 modem context used when receiving FAXes at 7200bps or
+               9600bps */
+    v29_rx_state_t v29_rx;
+
     /*! \brief Used to insert timed silences. */
     silence_gen_state_t silence_gen;
 
@@ -136,6 +139,28 @@ struct t31_state_s
     int32_t silence_threshold_power;
     
     t38_core_state_t t38;
+    int rx_signal_present;
+    /*! \brief The next queued tramsit indicator */
+    int next_tx_indicator;
+    /*! \brief The current T.38 data type being transmitted */
+    int current_tx_data_type;
+
+    int ms_per_tx_chunk;
+    int merge_tx_fields;
+
+    /*! \brief The number of times an indicator packet will be sent. Numbers greater than one
+               will increase reliability for UDP transmission. Zero is valid, to suppress all
+               indicator packets for TCP transmission. */
+    int indicator_tx_count;
+
+    /*! \brief The number of times a data packet which ends transmission will be sent. Numbers
+               greater than one will increase reliability for UDP transmission. Zero is not valid. */
+    int data_end_tx_count;
+
+    /*! \brief A "sample" count, used to time events */
+    int32_t samples;
+    int32_t next_tx_samples;
+    int32_t timeout_rx_samples;
 
 	/*! \brief Samples of silence heard */
     int silence_heard;
@@ -156,16 +181,18 @@ struct t31_state_s
     int t38_mode;
     int timed_step;
     int current_tx_data;
-    int64_t next_send_samples;
-    int next_tx_indicator;
 
     int current_rx_type;
     int current_tx_type;
 
+    int trailer_bytes;
+
     /*! \brief TRUE is there has been some T.38 data missed */
     int missing_data;
 
-    int octets_per_non_ecm_packet;
+    /*! \brief The number of octets to send in each image packet (non-ECM or ECM) at the current
+               rate and the current specified packet interval. */
+    int octets_per_data_packet;
 
     /*! \brief Error and flow logging control */
     logging_state_t logging;
@@ -208,6 +235,21 @@ int t31_t38_send_timeout(t31_state_t *s, int samples);
 */
 void t31_set_transmit_on_idle(t31_state_t *s, int transmit_on_idle);
 
+/*! Select whether TEP mode will be used (or time allowed for it (when transmitting).
+    \brief Select whether TEP mode will be used.
+    \param s The T.31 modem context.
+    \param use_tep TRUE if TEP is to be ised.
+*/
+void t31_set_tep_mode(t31_state_t *s, int use_tep);
+
+/*! Select whether T.38 data will be paced as it is transmitted.
+    \brief Select whether T.38 data will be paced.
+    \param s The T.31 modem context.
+    \param without_pacing TRUE if data is to be sent as fast as possible. FALSE if it is
+           to be paced.
+*/
+void t31_set_t38_config(t31_state_t *s, int without_pacing);
+
 /*! Initialise a T.31 context. This must be called before the first
     use of the context, to initialise its contents.
     \brief Initialise a T.31 context.
