@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: v27ter_rx.h,v 1.38 2007/04/10 16:12:20 steveu Exp $
+ * $Id: v27ter_rx.h,v 1.43 2007/12/13 11:31:33 steveu Exp $
  */
 
 /*! \file */
@@ -81,7 +81,11 @@ typedef struct
     void *qam_user_data;
 
     /*! \brief The route raised cosine (RRC) pulse shaping filter buffer. */
+#if defined(SPANDSP_USE_FIXED_POINT)
+    int16_t rrc_filter[2*V27TER_RX_FILTER_STEPS];
+#else
     float rrc_filter[2*V27TER_RX_FILTER_STEPS];
+#endif
     /*! \brief Current offset into the RRC pulse shaping filter buffer. */
     int rrc_filter_step;
 
@@ -92,8 +96,12 @@ typedef struct
     int scrambler_pattern_count;
     /*! \brief The section of the training data we are currently in. */
     int training_stage;
+    /*! \brief The current step in the table of BC constellation positions. */
     int training_bc;
+    /*! \brief A count of how far through the current training step we are. */
     int training_count;
+    /*! \brief A measure of how much mismatch there is between the real constellation,
+        and the decoded symbol positions. */
     float training_error;
     /*! \brief The value of the last signal sample, using the a simple HPF for signal power estimation. */
     int16_t last_sample;
@@ -101,6 +109,10 @@ typedef struct
     int signal_present;
     /*! \brief Whether or not a carrier drop was detected and the signal delivery is pending. */
     int carrier_drop_pending;
+    /*! \brief A count of the current consecutive samples below the carrier off threshold. */
+    int low_samples;
+    /*! \brief A highest magnitude sample seen. */
+    int16_t high_sample;
     /*! \brief TRUE if the previous trained values are to be reused. */
     int old_train;
 
@@ -110,25 +122,43 @@ typedef struct
     int32_t carrier_phase_rate;
     /*! \brief The carrier update rate saved for reuse when using short training. */
     int32_t carrier_phase_rate_save;
+    /*! \brief The proportional part of the carrier tracking filter. */
     float carrier_track_p;
+    /*! \brief The integral part of the carrier tracking filter. */
     float carrier_track_i;
 
+    /*! \brief A power meter, to measure the HPF'ed signal power in the channel. */    
     power_meter_t power;
+    /*! \brief The power meter level at which carrier on is declared. */
     int32_t carrier_on_power;
+    /*! \brief The power meter level at which carrier off is declared. */
     int32_t carrier_off_power;
+    /*! \brief The scaling factor accessed by the AGC algorithm. */
     float agc_scaling;
+    /*! \brief The previous value of agc_scaling, needed to reuse old training. */
     float agc_scaling_save;
 
     int constellation_state;
 
+    /*! \brief The current delta factor for updating the equalizer coefficients. */
     float eq_delta;
-    /*! \brief The adaptive equalizer coefficients */
+#if defined(SPANDSP_USE_FIXED_POINTx)
+    /*! \brief The adaptive equalizer coefficients. */
+    complexi_t eq_coeff[V27TER_EQUALIZER_PRE_LEN + 1 + V27TER_EQUALIZER_POST_LEN];
+    /*! \brief A saved set of adaptive equalizer coefficients for use after restarts. */
+    complexi_t eq_coeff_save[V27TER_EQUALIZER_PRE_LEN + 1 + V27TER_EQUALIZER_POST_LEN];
+    /*! \brief The equalizer signal buffer. */
+    complexi_t eq_buf[V27TER_EQUALIZER_MASK + 1];
+#else
     complexf_t eq_coeff[V27TER_EQUALIZER_PRE_LEN + 1 + V27TER_EQUALIZER_POST_LEN];
     complexf_t eq_coeff_save[V27TER_EQUALIZER_PRE_LEN + 1 + V27TER_EQUALIZER_POST_LEN];
     complexf_t eq_buf[V27TER_EQUALIZER_MASK + 1];
-    /*! \brief Current offset into equalizer buffer. */
+#endif
+    /*! \brief Current offset into the equalizer buffer. */
     int eq_step;
+    /*! \brief Current write offset into the equalizer buffer. */
     int eq_put_step;
+    /*! \brief Symbol counter to the next equalizer update. */
     int eq_skip;
 
     /*! \brief Integration variable for damping the Gardner algorithm tests. */
@@ -149,7 +179,7 @@ typedef struct
     logging_state_t logging;
 } v27ter_rx_state_t;
 
-#ifdef __cplusplus
+#if defined(__cplusplus)
 extern "C"
 {
 #endif
@@ -171,11 +201,11 @@ v27ter_rx_state_t *v27ter_rx_init(v27ter_rx_state_t *s, int rate, put_bit_func_t
     \return 0 for OK, -1 for bad parameter */
 int v27ter_rx_restart(v27ter_rx_state_t *s, int rate, int old_train);
 
-/*! Release a V.27ter modem receive context.
-    \brief Release a V.27ter modem receive context.
+/*! Free a V.27ter modem receive context.
+    \brief Free a V.27ter modem receive context.
     \param s The modem context.
     \return 0 for OK */
-int v27ter_rx_release(v27ter_rx_state_t *s);
+int v27ter_rx_free(v27ter_rx_state_t *s);
 
 /*! Change the put_bit function associated with a V.27ter modem receive context.
     \brief Change the put_bit function associated with a V.27ter modem receive context.
@@ -225,7 +255,7 @@ void v27ter_rx_signal_cutoff(v27ter_rx_state_t *s, float cutoff);
     \param user_data An opaque pointer passed to the handler routine. */
 void v27ter_rx_set_qam_report_handler(v27ter_rx_state_t *s, qam_report_handler_t *handler, void *user_data);
 
-#ifdef __cplusplus
+#if defined(__cplusplus)
 }
 #endif
 
