@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: v29rx.h,v 1.45 2007/04/10 16:12:20 steveu Exp $
+ * $Id: v29rx.h,v 1.51 2007/12/13 11:31:33 steveu Exp $
  */
 
 /*! \file */
@@ -150,7 +150,11 @@ typedef struct
     void *qam_user_data;
 
     /*! \brief The route raised cosine (RRC) pulse shaping filter buffer. */
+#if defined(SPANDSP_USE_FIXED_POINT)
+    int16_t rrc_filter[2*V29_RX_FILTER_STEPS];
+#else
     float rrc_filter[2*V29_RX_FILTER_STEPS];
+#endif
     /*! \brief Current offset into the RRC pulse shaping filter buffer. */
     int rrc_filter_step;
 
@@ -160,8 +164,12 @@ typedef struct
     uint8_t training_scramble_reg;
     /*! \brief The section of the training data we are currently in. */
     int training_stage;
+    /*! \brief The current step in the table of CD constellation positions. */
     int training_cd;
+    /*! \brief A count of how far through the current training step we are. */
     int training_count;
+    /*! \brief A measure of how much mismatch there is between the real constellation,
+        and the decoded symbol positions. */
     float training_error;
     /*! \brief The value of the last signal sample, using the a simple HPF for signal power estimation. */
     int16_t last_sample;
@@ -169,7 +177,10 @@ typedef struct
     int signal_present;
     /*! \brief Whether or not a carrier drop was detected and the signal delivery is pending. */
     int carrier_drop_pending;
-
+    /*! \brief A count of the current consecutive samples below the carrier off threshold. */
+    int low_samples;
+    /*! \brief A highest magnitude sample seen. */
+    int16_t high_sample;
     /*! \brief TRUE if the previous trained values are to be reused. */
     int old_train;
 
@@ -179,34 +190,67 @@ typedef struct
     int32_t carrier_phase_rate;
     /*! \brief The carrier update rate saved for reuse when using short training. */
     int32_t carrier_phase_rate_save;
+    /*! \brief The proportional part of the carrier tracking filter. */
     float carrier_track_p;
+    /*! \brief The integral part of the carrier tracking filter. */
     float carrier_track_i;
-    
+
+    /*! \brief A power meter, to measure the HPF'ed signal power in the channel. */    
     power_meter_t power;
+    /*! \brief The power meter level at which carrier on is declared. */
     int32_t carrier_on_power;
+    /*! \brief The power meter level at which carrier off is declared. */
     int32_t carrier_off_power;
+    /*! \brief The scaling factor accessed by the AGC algorithm. */
     float agc_scaling;
+    /*! \brief The previous value of agc_scaling, needed to reuse old training. */
     float agc_scaling_save;
 
     int constellation_state;
 
+    /*! \brief The current delta factor for updating the equalizer coefficients. */
     float eq_delta;
-    /*! \brief The adaptive equalizer coefficients */
+#if defined(SPANDSP_USE_FIXED_POINTx)
+    /*! \brief The adaptive equalizer coefficients. */
+    complexi_t eq_coeff[V29_EQUALIZER_PRE_LEN + 1 + V29_EQUALIZER_POST_LEN];
+    /*! \brief A saved set of adaptive equalizer coefficients for use after restarts. */
+    complexi_t eq_coeff_save[V29_EQUALIZER_PRE_LEN + 1 + V29_EQUALIZER_POST_LEN];
+    /*! \brief The equalizer signal buffer. */
+    complexi_t eq_buf[V29_EQUALIZER_MASK + 1];
+#else
     complexf_t eq_coeff[V29_EQUALIZER_PRE_LEN + 1 + V29_EQUALIZER_POST_LEN];
     complexf_t eq_coeff_save[V29_EQUALIZER_PRE_LEN + 1 + V29_EQUALIZER_POST_LEN];
     complexf_t eq_buf[V29_EQUALIZER_MASK + 1];
-    /*! \brief Current offset into equalizer buffer. */
+#endif
+    /*! \brief Current offset into the equalizer buffer. */
     int eq_step;
+    /*! \brief Current write offset into the equalizer buffer. */
     int eq_put_step;
+    /*! \brief Symbol counter to the next equalizer update. */
     int eq_skip;
 
     /*! \brief The current half of the baud. */
     int baud_half;
-    /*! \brief Band edge symbol sync. filter state. */
+#if defined(SPANDSP_USE_FIXED_POINTx)
+    /*! Low band edge filter for symbol sync. */
+    int32_t symbol_sync_low[2];
+    /*! High band edge filter for symbol sync. */
+    int32_t symbol_sync_high[2];
+    /*! DC filter for symbol sync. */
+    int32_t symbol_sync_dc_filter[2];
+    /*! Baud phase for symbol sync. */
+    int32_t baud_phase;
+#else
+    /*! Low band edge filter for symbol sync. */
     float symbol_sync_low[2];
+    /*! High band edge filter for symbol sync. */
     float symbol_sync_high[2];
+    /*! DC filter for symbol sync. */
     float symbol_sync_dc_filter[2];
+    /*! Baud phase for symbol sync. */
     float baud_phase;
+#endif
+
     /*! \brief The total symbol timing correction since the carrier came up.
                This is only for performance analysis purposes. */
     int total_baud_timing_correction;
@@ -219,7 +263,7 @@ typedef struct
     logging_state_t logging;
 } v29_rx_state_t;
 
-#ifdef __cplusplus
+#if defined(__cplusplus)
 extern "C"
 {
 #endif
@@ -241,11 +285,11 @@ v29_rx_state_t *v29_rx_init(v29_rx_state_t *s, int rate, put_bit_func_t put_bit,
     \return 0 for OK, -1 for bad parameter */
 int v29_rx_restart(v29_rx_state_t *s, int rate, int old_train);
 
-/*! Release a V.29 modem receive context.
-    \brief Release a V.29 modem receive context.
+/*! Free a V.29 modem receive context.
+    \brief Free a V.29 modem receive context.
     \param s The modem context.
     \return 0 for OK */
-int v29_rx_release(v29_rx_state_t *s);
+int v29_rx_free(v29_rx_state_t *s);
 
 /*! Change the put_bit function associated with a V.29 modem receive context.
     \brief Change the put_bit function associated with a V.29 modem receive context.
@@ -295,7 +339,7 @@ void v29_rx_signal_cutoff(v29_rx_state_t *s, float cutoff);
     \param user_data An opaque pointer passed to the handler routine. */
 void v29_rx_set_qam_report_handler(v29_rx_state_t *s, qam_report_handler_t *handler, void *user_data);
 
-#ifdef __cplusplus
+#if defined(__cplusplus)
 }
 #endif
 
