@@ -23,7 +23,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: bell_mf_rx_tests.c,v 1.5 2006/10/24 13:45:28 steveu Exp $
+ * $Id: bell_mf_rx_tests.c,v 1.7 2007/11/10 11:14:57 steveu Exp $
  */
 
 /*! \file */
@@ -43,15 +43,12 @@ a fair test of performance in a real PSTN channel.
 #include "config.h"
 #endif
 
-#include <math.h>
-#include <inttypes.h>
 #include <stdlib.h>
-#include <string.h>
 #include <stdio.h>
-#include <time.h>
 #include <fcntl.h>
+#include <string.h>
+#include <time.h>
 #include <audiofile.h>
-#include <tiffio.h>
 
 #include "spandsp.h"
 
