@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: dtmf_tx_tests.c,v 1.10 2006/10/24 13:45:29 steveu Exp $
+ * $Id: dtmf_tx_tests.c,v 1.13 2007/11/10 11:14:58 steveu Exp $
  */
 
 /*! \file */
@@ -40,14 +40,11 @@
 #endif
 
 #include <stdlib.h>
-#include <math.h>
-#include <inttypes.h>
 #include <string.h>
 #include <stdio.h>
-#include <time.h>
 #include <fcntl.h>
+#include <time.h>
 #include <audiofile.h>
-#include <tiffio.h>
 
 #include "spandsp.h"
 
@@ -84,22 +81,22 @@ int main(int argc, char *argv[])
     len = dtmf_tx(&gen, amp, 16384);
     printf("Generated %d samples\n", len);
     outframes = afWriteFrames(outhandle, AF_DEFAULT_TRACK, amp, len);
-    if (dtmf_tx_put(&gen, "123"))
+    if (dtmf_tx_put(&gen, "123", -1))
         printf("Ooops\n");
     len = dtmf_tx(&gen, amp, 16384);
     printf("Generated %d samples\n", len);
     outframes = afWriteFrames(outhandle, AF_DEFAULT_TRACK, amp, len);
-    if (dtmf_tx_put(&gen, "456"))
+    if (dtmf_tx_put(&gen, "456", -1))
         printf("Ooops\n");
     len = dtmf_tx(&gen, amp, 160);
     printf("Generated %d samples\n", len);
     outframes = afWriteFrames(outhandle, AF_DEFAULT_TRACK, amp, len);
-    if (dtmf_tx_put(&gen, "789"))
+    if (dtmf_tx_put(&gen, "789", -1))
         printf("Ooops\n");
     len = dtmf_tx(&gen, amp, 160);
     printf("Generated %d samples\n", len);
     outframes = afWriteFrames(outhandle, AF_DEFAULT_TRACK, amp, len);
-    if (dtmf_tx_put(&gen, "*#"))
+    if (dtmf_tx_put(&gen, "*#", -1))
         printf("Ooops\n");
     len = dtmf_tx(&gen, amp, 160);
     printf("Generated %d samples\n", len);
@@ -115,7 +112,7 @@ int main(int argc, char *argv[])
         }
         if (add_digits)
         {
-            if (dtmf_tx_put(&gen, "1234567890"))
+            if (dtmf_tx_put(&gen, "1234567890", -1))
             {
                 printf("Digit buffer full\n");
                 add_digits = 0;
@@ -128,27 +125,27 @@ int main(int argc, char *argv[])
     len = dtmf_tx(&gen, amp, 16384);
     printf("Generated %d samples\n", len);
     outframes = afWriteFrames(outhandle, AF_DEFAULT_TRACK, amp, len);
-    if (dtmf_tx_put(&gen, "123"))
+    if (dtmf_tx_put(&gen, "123", -1))
         printf("Ooops\n");
     len = dtmf_tx(&gen, amp, 16384);
     printf("Generated %d samples\n", len);
     outframes = afWriteFrames(outhandle, AF_DEFAULT_TRACK, amp, len);
-    if (dtmf_tx_put(&gen, "456"))
+    if (dtmf_tx_put(&gen, "456", -1))
         printf("Ooops\n");
     len = dtmf_tx(&gen, amp, 160);
     printf("Generated %d samples\n", len);
     outframes = afWriteFrames(outhandle, AF_DEFAULT_TRACK, amp, len);
-    if (dtmf_tx_put(&gen, "789"))
+    if (dtmf_tx_put(&gen, "789", -1))
         printf("Ooops\n");
     len = dtmf_tx(&gen, amp, 160);
     printf("Generated %d samples\n", len);
     outframes = afWriteFrames(outhandle, AF_DEFAULT_TRACK, amp, len);
-    if (dtmf_tx_put(&gen, "0*#"))
+    if (dtmf_tx_put(&gen, "0*#", -1))
         printf("Ooops\n");
     len = dtmf_tx(&gen, amp, 160);
     printf("Generated %d samples\n", len);
     outframes = afWriteFrames(outhandle, AF_DEFAULT_TRACK, amp, len);
-    if (dtmf_tx_put(&gen, "ABCD"))
+    if (dtmf_tx_put(&gen, "ABCD", -1))
         printf("Ooops\n");
     len = dtmf_tx(&gen, amp, 160);
     printf("Generated %d samples\n", len);
@@ -164,7 +161,7 @@ int main(int argc, char *argv[])
         }
         if (add_digits)
         {
-            if (dtmf_tx_put(&gen, "1234567890"))
+            if (dtmf_tx_put(&gen, "1234567890", -1))
             {
                 printf("Digit buffer full\n");
                 add_digits = 0;
