@@ -25,7 +25,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: echo_tests.c,v 1.26 2006/10/24 13:45:29 steveu Exp $
+ * $Id: echo_tests.c,v 1.29 2007/11/10 11:14:58 steveu Exp $
  */
 
 /*! \page echo_can_tests_page Line echo cancellation for voice tests
@@ -48,18 +48,13 @@ all the tests in G.168 are fully implemented at this time.
 #define ENABLE_GUI
 #endif
 
-#define _GNU_SOURCE
-
-#include <unistd.h>
-#include <inttypes.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <unistd.h>
 #include <string.h>
 #include <strings.h>
-#include <math.h>
 #include <assert.h>
 #include <audiofile.h>
-#include <tiffio.h>
 
 #define GEN_CONST
 #include <math.h>
