@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: line_model_tests.c,v 1.14 2006/10/24 13:45:29 steveu Exp $
+ * $Id: line_model_tests.c,v 1.20 2007/11/10 11:14:58 steveu Exp $
  */
 
 /*! \page line_model_tests_page Telephony line model tests
@@ -38,32 +38,84 @@
 #endif
 
 #include <stdlib.h>
-#include <unistd.h>
-#include <inttypes.h>
-#include <string.h>
-#include <time.h>
 #include <stdio.h>
 #include <fcntl.h>
+#include <unistd.h>
+#include <string.h>
+#include <time.h>
 #include <audiofile.h>
-#include <tiffio.h>
-
-#define GEN_CONST
-#include <math.h>
 
 #include "spandsp.h"
-#include "test_utils.h"
-#include "line_model.h"
+#include "spandsp-sim.h"
 
 #if !defined(NULL)
 #define NULL (void *) 0
 #endif
 
-#define BLOCK_LEN       160
+#define BLOCK_LEN           160
 
-#define IN_FILE_NAME1   "line_model_test_in1.wav"
-#define IN_FILE_NAME2   "line_model_test_in2.wav"
-#define OUT_FILE_NAME1  "line_model_one_way_test_out.wav"
-#define OUT_FILE_NAME   "line_model_test_out.wav"
+#define OUT_FILE_COMPLEXIFY "complexify.wav"
+#define IN_FILE_NAME1       "line_model_test_in1.wav"
+#define IN_FILE_NAME2       "line_model_test_in2.wav"
+#define OUT_FILE_NAME1      "line_model_one_way_test_out.wav"
+#define OUT_FILE_NAME       "line_model_test_out.wav"
+
+int channel_codec;
+int rbs_pattern;
+
+static void complexify_tests(void)
+{
+    complexify_state_t *s;
+    complexf_t cc;
+    int16_t amp;
+    int i;
+    AFfilehandle outhandle;
+    AFfilesetup filesetup;
+    int outframes;
+    int16_t out[40000];
+    awgn_state_t noise1;
+    
+    if ((filesetup = afNewFileSetup()) == AF_NULL_FILESETUP)
+    {
+        fprintf(stderr, "    Failed to create file setup\n");
+        exit(2);
+    }
+    afInitSampleFormat(filesetup, AF_DEFAULT_TRACK, AF_SAMPFMT_TWOSCOMP, 16);
+    afInitRate(filesetup, AF_DEFAULT_TRACK, (float) SAMPLE_RATE);
+    afInitFileFormat(filesetup, AF_FILE_WAVE);
+    afInitChannels(filesetup, AF_DEFAULT_TRACK, 2);
+
+    if ((outhandle = afOpenFile(OUT_FILE_COMPLEXIFY, "w", filesetup)) == AF_NULL_FILEHANDLE)
+    {
+        fprintf(stderr, "    Cannot create wave file '%s'\n", OUT_FILE_COMPLEXIFY);
+        exit(2);
+    }
+    awgn_init_dbm0(&noise1, 1234567, -10.0f);
+    s = complexify_init();
+    for (i = 0;  i < 20000;  i++)
+    {
+        amp = awgn(&noise1);
+        cc = complexify(s, amp);
+        out[2*i] = cc.re;
+        out[2*i + 1] = cc.im;
+    }
+    outframes = afWriteFrames(outhandle,
+                              AF_DEFAULT_TRACK,
+                              out,
+                              20000);
+    if (outframes != 20000)
+    {
+        fprintf(stderr, "    Error writing wave file\n");
+        exit(2);
+    }
+    if (afCloseFile(outhandle))
+    {
+        fprintf(stderr, "    Cannot close wave file '%s'\n", OUT_FILE_COMPLEXIFY);
+        exit(2);
+    }
+    afFreeFileSetup(filesetup);
+}
+/*- End of function --------------------------------------------------------*/
 
 static void test_one_way_model(int line_model_no, int speech_test)
 {
@@ -80,7 +132,7 @@ static void test_one_way_model(int line_model_no, int speech_test)
     int j;
     awgn_state_t noise1;
     
-    if ((model = one_way_line_model_init(line_model_no, -50, MUNGE_CODEC_ALAW)) == NULL)
+    if ((model = one_way_line_model_init(line_model_no, -50, channel_codec, rbs_pattern)) == NULL)
     {
         fprintf(stderr, "    Failed to create line model\n");
         exit(2);
@@ -156,6 +208,7 @@ static void test_one_way_model(int line_model_no, int speech_test)
     afFreeFileSetup(filesetup);
     one_way_line_model_release(model);
 }
+/*- End of function --------------------------------------------------------*/
 
 static void test_both_ways_model(int line_model_no, int speech_test)
 {
@@ -176,7 +229,7 @@ static void test_both_ways_model(int line_model_no, int speech_test)
     awgn_state_t noise1;
     awgn_state_t noise2;
     
-    if ((model = both_ways_line_model_init(line_model_no, -50, line_model_no + 1, -35, MUNGE_CODEC_ALAW)) == NULL)
+    if ((model = both_ways_line_model_init(line_model_no, -50, line_model_no + 1, -35, channel_codec, rbs_pattern)) == NULL)
     {
         fprintf(stderr, "    Failed to create line model\n");
         exit(2);
@@ -285,13 +338,42 @@ int main(int argc, char *argv[])
 {
     int line_model_no;
     int speech_test;
+    int log_audio;
+    int i;
 
-    line_model_no = 5;
-    speech_test = TRUE;
-    if (argc > 1)
-        line_model_no = atoi(argv[1]);
-    if (argc > 2)
-        speech_test = FALSE;
+    line_model_no = 0;
+    speech_test = FALSE;
+    log_audio = FALSE;
+    channel_codec = MUNGE_CODEC_NONE;
+    for (i = 1;  i < argc;  i++)
+    {
+        if (strcmp(argv[i], "-c") == 0)
+        {
+            channel_codec = atoi(argv[++i]);
+            continue;
+        }
+        if (strcmp(argv[i], "-l") == 0)
+        {
+            log_audio = TRUE;
+            continue;
+        }
+        if (strcmp(argv[i], "-m") == 0)
+        {
+            line_model_no = atoi(argv[++i]);
+            continue;
+        }
+        if (strcmp(argv[i], "-r") == 0)
+        {
+            rbs_pattern = atoi(argv[++i]);
+            continue;
+        }
+        if (strcmp(argv[i], "-s") == 0)
+        {
+            speech_test = TRUE;
+            continue;
+        }
+    }
+    complexify_tests();
     test_one_way_model(line_model_no, speech_test);
     test_both_ways_model(line_model_no, speech_test);
 }
