@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: playout_tests.c,v 1.13 2006/10/24 13:22:03 steveu Exp $
+ * $Id: playout_tests.c,v 1.18 2007/11/26 13:29:00 steveu Exp $
  */
 
 /*! \page playout_tests_page Playout (jitter buffering) tests
@@ -31,13 +31,13 @@ These tests simulate timing jitter and packet loss in an audio stream, and see
 how well the playout module copes.
 */
 
-#include <stdio.h>
-#include <inttypes.h>
-#include <stdlib.h>
-#include <string.h>
-#include <tgmath.h>
-#include <tiffio.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
 #include <audiofile.h>
 
 #include "spandsp.h"
@@ -53,7 +53,7 @@ static void dynamic_buffer_tests(void)
     playout_frame_t frame;
     playout_frame_t *p;
     plc_state_t plc;
-    time_scale_t ts;
+    time_scale_state_t ts;
     int16_t *amp;
     int16_t fill[BLOCK_LEN];
     int16_t buf[20*BLOCK_LEN];
@@ -104,7 +104,7 @@ static void dynamic_buffer_tests(void)
     for (i = 0;  i < BLOCK_LEN;  i++)
         fill[i] = 32767;
 
-	if ((s = playout_new(2*BLOCK_LEN, 15*BLOCK_LEN)) == NULL)
+    if ((s = playout_new(2*BLOCK_LEN, 15*BLOCK_LEN)) == NULL)
         return;
     plc_init(&plc);
     time_scale_init(&ts, 1.0);
@@ -234,11 +234,11 @@ printf("len = %d\n", len);
     }
     afFreeFileSetup(filesetup);
 
-    printf("%10d %10d %10d\n", s->state_just_in_time, s->state_late, playout_current_length(s));
+    printf("%10" PRId32 " %10" PRId32 " %10d\n", s->state_just_in_time, s->state_late, playout_current_length(s));
 
     /* Clear everything from the queue */
     while ((p = playout_get_unconditional(s)))
-		/*free(p->data)*/;
+        /*free(p->data)*/;
     /* Now free the context itself */
     playout_free(s);
 }
@@ -338,7 +338,7 @@ static void static_buffer_tests(void)
     }
     /* Clear everything from the queue */
     while ((p = playout_get_unconditional(s)))
-		/*free(p->data)*/;
+        /*free(p->data)*/;
     /* Now free the context itself */
     playout_free(s);
 }
