@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: r2_mf_tx_tests.c,v 1.6 2006/12/27 04:09:46 steveu Exp $
+ * $Id: r2_mf_tx_tests.c,v 1.7 2007/11/10 11:14:58 steveu Exp $
  */
 
 /*! \file */
@@ -40,19 +40,11 @@
 #endif
 
 #include <stdlib.h>
-#include <inttypes.h>
-#include <string.h>
 #include <stdio.h>
-#if defined(HAVE_TGMATH_H)
-#include <tgmath.h>
-#endif
-#if defined(HAVE_MATH_H)
-#include <math.h>
-#endif
-#include <time.h>
 #include <fcntl.h>
+#include <string.h>
+#include <time.h>
 #include <audiofile.h>
-#include <tiffio.h>
 
 #include "spandsp.h"
 
