@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: v29_tests.c,v 1.86 2007/06/29 12:56:28 steveu Exp $
+ * $Id: v29_tests.c,v 1.92 2007/12/29 04:16:29 steveu Exp $
  */
 
 /*! \page v29_tests_page V.29 modem tests
@@ -53,20 +53,12 @@ display of modem status is maintained.
 #define ENABLE_GUI
 #endif
 
-#include <inttypes.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <fcntl.h>
+#include <unistd.h>
 #include <string.h>
-#if defined(HAVE_TGMATH_H)
-#include <tgmath.h>
-#endif
-#if defined(HAVE_MATH_H)
-#include <math.h>
-#endif
-#include <assert.h>
 #include <audiofile.h>
-#include <tiffio.h>
 
 #include "spandsp.h"
 #include "spandsp-sim.h"
@@ -193,7 +185,7 @@ static void qam_report(void *user_data, const complexf_t *constel, const complex
     complexf_t *coeffs;
     float fpower;
     v29_rx_state_t *rx;
-    static float smooth_power = 0.0;
+    static float smooth_power = 0.0f;
     static int update_interval = 100;
 
     rx = (v29_rx_state_t *) user_data;
@@ -201,22 +193,23 @@ static void qam_report(void *user_data, const complexf_t *constel, const complex
     {
         fpower = (constel->re - target->re)*(constel->re - target->re)
                + (constel->im - target->im)*(constel->im - target->im);
-        smooth_power = 0.95*smooth_power + 0.05*fpower;
+        smooth_power = 0.95f*smooth_power + 0.05f*fpower;
 #if defined(ENABLE_GUI)
         if (use_gui)
         {
             qam_monitor_update_constel(qam_monitor, constel);
             qam_monitor_update_carrier_tracking(qam_monitor, v29_rx_carrier_frequency(rx));
-            //qam_monitor_update_carrier_tracking(qam_monitor, (fpower)  ?  fpower  :  0.001);
+            //qam_monitor_update_carrier_tracking(qam_monitor, (fpower)  ?  fpower  :  0.001f);
             qam_monitor_update_symbol_tracking(qam_monitor, v29_rx_symbol_timing_correction(rx));
         }
 #endif
-        printf("%8d [%8.4f, %8.4f] [%8.4f, %8.4f] %8.4f %8.4f %9.4f %7.3f %7.1f\n",
+        printf("%8d [%8.4f, %8.4f] [%8.4f, %8.4f] %2x %8.4f %8.4f %9.4f %7.3f %7.2f\n",
                symbol_no,
                constel->re,
                constel->im,
                target->re,
                target->im,
+               symbol,
                fpower,
                smooth_power,
                v29_rx_carrier_frequency(rx),
@@ -251,7 +244,6 @@ int main(int argc, char *argv[])
     AFfilesetup filesetup;
     int outframes;
     int samples;
-    int i;
     int tep;
     int test_bps;
     int noise_level;
@@ -263,6 +255,7 @@ int main(int argc, char *argv[])
     int channel_codec;
     int rbs_pattern;
     float x;
+    int opt;
     
     channel_codec = MUNGE_CODEC_NONE;
     rbs_pattern = 0;
@@ -275,63 +268,60 @@ int main(int argc, char *argv[])
     signal_level = -13;
     bits_per_test = 50000;
     log_audio = FALSE;
-    for (i = 1;  i < argc;  i++)
+    while ((opt = getopt(argc, argv, "b:c:d:glm:n:r:s:t")) != -1)
     {
-        if (strcmp(argv[i], "-b") == 0)
-        {
-            bits_per_test = atoi(argv[++i]);
-            continue;
-        }
-        if (strcmp(argv[i], "-c") == 0)
-        {
-            channel_codec = atoi(argv[++i]);
-            continue;
-        }
-        if (strcmp(argv[i], "-d") == 0)
-        {
-            decode_test_file = argv[++i];
-            continue;
-        }
-        if (strcmp(argv[i], "-g") == 0)
+        switch (opt)
         {
+        case 'b':
+            bits_per_test = atoi(optarg);
+            break;
+        case 'c':
+            channel_codec = atoi(optarg);
+            break;
+        case 'd':
+            decode_test_file = optarg;
+            break;
+        case 'g':
+#if defined(ENABLE_GUI)
             use_gui = TRUE;
-            continue;
-        }
-        if (strcmp(argv[i], "-l") == 0)
-        {
+#else
+            fprintf(stderr, "Graphical monitoring not available\n");
+            exit(2);
+#endif
+            break;
+        case 'l':
             log_audio = TRUE;
-            continue;
-        }
-        if (strcmp(argv[i], "-m") == 0)
-        {
-            line_model_no = atoi(argv[++i]);
-            continue;
-        }
-        if (strcmp(argv[i], "-n") == 0)
-        {
-            noise_level = atoi(argv[++i]);
-            continue;
-        }
-        if (strcmp(argv[i], "-r") == 0)
-        {
-            rbs_pattern = atoi(argv[++i]);
-            continue;
-        }
-        if (strcmp(argv[i], "-s") == 0)
-        {
-            signal_level = atoi(argv[++i]);
-            continue;
-        }
-        if (strcmp(argv[i], "-t") == 0)
-        {
+            break;
+        case 'm':
+            line_model_no = atoi(optarg);
+            break;
+        case 'n':
+            noise_level = atoi(optarg);
+            break;
+        case 'r':
+            rbs_pattern = atoi(optarg);
+            break;
+        case 's':
+            signal_level = atoi(optarg);
+            break;
+        case 't':
             tep = TRUE;
-            continue;
+            break;
+        default:
+            //usage();
+            exit(2);
+            break;
         }
-        if (strcmp(argv[i], "9600") == 0)
+    }
+    argc -= optind;
+    argv += optind;
+    if (argc > 0)
+    {
+        if (strcmp(argv[0], "9600") == 0)
             test_bps = 9600;
-        else if (strcmp(argv[i], "7200") == 0)
+        else if (strcmp(argv[0], "7200") == 0)
             test_bps = 7200;
-        else if (strcmp(argv[i], "4800") == 0)
+        else if (strcmp(argv[0], "4800") == 0)
             test_bps = 4800;
         else
         {
@@ -369,7 +359,7 @@ int main(int argc, char *argv[])
             fprintf(stderr, "    Cannot open wave file '%s'\n", decode_test_file);
             exit(2);
         }
-        if ((x = afGetFrameSize(inhandle, AF_DEFAULT_TRACK, 1)) != 2.0)
+        if ((x = afGetFrameSize(inhandle, AF_DEFAULT_TRACK, 1)) != 2.0f)
         {
             printf("    Unexpected frame size in speech file '%s'\n", decode_test_file);
             exit(2);
@@ -379,7 +369,7 @@ int main(int argc, char *argv[])
             printf("    Unexpected sample rate in speech file '%s'\n", decode_test_file);
             exit(2);
         }
-        if ((x = afGetChannels(inhandle, AF_DEFAULT_TRACK)) != 1.0)
+        if ((x = afGetChannels(inhandle, AF_DEFAULT_TRACK)) != 1.0f)
         {
             printf("    Unexpected number of channels in speech file '%s'\n", decode_test_file);
             exit(2);
@@ -405,7 +395,7 @@ int main(int argc, char *argv[])
     }
 
     v29_rx_init(&rx, test_bps, v29putbit, &rx);
-    v29_rx_signal_cutoff(&rx, -45.5);
+    v29_rx_signal_cutoff(&rx, -45.5f);
     v29_rx_set_qam_report_handler(&rx, qam_report, (void *) &rx);
     /* Rotate the starting phase */
     rx.carrier_phase = 0x80000000;
@@ -415,7 +405,7 @@ int main(int argc, char *argv[])
 #if defined(ENABLE_GUI)
     if (use_gui)
     {
-        qam_monitor = qam_monitor_init(6.0, NULL);
+        qam_monitor = qam_monitor_init(6.0f, NULL);
         if (!decode_test_file)
         {
             start_line_model_monitor(129);
